@@ -87,7 +87,9 @@ class View(object):
             self.authenticate(*args, **kwargs)
 
             # Dispatch
+            self.pre_handle(*args, **kwargs)
             handler(*args, **kwargs)
+            self.post_handle(*args, **kwargs)
 
         # Handler
         except ViewError, e:
@@ -117,6 +119,12 @@ class View(object):
 
         return self._put
 
+    def pre_handle(self, *args, **kwargs):
+        pass
+
+    def post_handle(self, *args, **kwargs):
+        pass
+
     def only_accept_https(self, *args, **kwargs):
         return getattr(settings, HTTPS_ONLY, False)
 
